==> haskell-typed-process-0.2.4.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: typed-process
version: 0.2.4.0
id: typed-process-0.2.4.0-AouJXmLFxe411fnXMKZHjY
key: typed-process-0.2.4.0-AouJXmLFxe411fnXMKZHjY
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://haskell-lang.org/library/typed-process
synopsis: Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>
category: System
abi: 4b30b8253c45fee7c1ce0eadfff5bcae
exposed: True
exposed-modules:
    System.Process.Typed
hidden-modules: Paths_typed_process
import-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/typed-process-0.2.4.0
hs-libraries: HStyped-process-0.2.4.0-AouJXmLFxe411fnXMKZHjY
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 stm-2.5.0.0
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-typed-process/html/typed-process.haddock
haddock-html: /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.4.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: typed-process
version: 0.2.4.0
id: typed-process-0.2.4.0-Iiuu0PrdfPTETKY6YotJZu
key: typed-process-0.2.4.0-Iiuu0PrdfPTETKY6YotJZu
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://haskell-lang.org/library/typed-process
synopsis: Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>
category: System
abi: 499f014417e44ba2ddc53878d0ba20e5
exposed: True
exposed-modules:
    System.Process.Typed
hidden-modules: Paths_typed_process
import-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/typed-process-0.2.4.0
hs-libraries: HStyped-process-0.2.4.0-Iiuu0PrdfPTETKY6YotJZu
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 stm-2.5.0.0
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-typed-process/html/typed-process.haddock
haddock-html: /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
